#!/bin/env perl

use strict;
use Getopt::Long;
use File::Basename qw(dirname);
use Sys::Hostname;

use DE_EPAGES::Core::API::File qw ( GetFileContent);
use DE_EPAGES::Core::API::Script qw( RunScript );
use DE_EPAGES::Database::API::Config qw( BusinessUnits );

sub Main {
    local $| = 1;

    my %Options;
    my @GetOpt = qw(version=s);
    die "GetOptions() failed\n" unless GetOptions(\%Options, @GetOpt);

    chdir dirname $0;
    chdir '..';

    if (not $Options{version}) {
        my $Version = GetFileContent('version.txt');
        chomp $$Version;
        $Options{version} = $$Version;
    }

    my $VersionFile = "$ENV{EPAGES_CONFIG}/hotfixes/version-". hostname(). '.txt';
    my $InstalledVersions;
    if (-f $VersionFile) {
        $InstalledVersions = GetFileContent($VersionFile);
        die "Hotfix $Options{version} can't be applied because already installed.\n".
            "(see $VersionFile)\n"
            if $$InstalledVersions =~ /(^|\n)\Q$Options{version}\E(\n|$)/;
    }

    return unless $Options{version} =~ /^(\d+)\.(\d+)\.(\d+)\.(\d+)$/;
    my ($Main, $Sub, $Patch, $HF) = ($1, $2, $3, $4);

    my $StoreConf = BusinessUnits();
    my $BU = (keys %$StoreConf)[0];
    my $CoreVersion = $StoreConf->{$BU}{Cartridges}{'DE_EPAGES::Core'};

    die "Hotfix $Options{version} can't be applied to DE_EPAGES::Core $CoreVersion.\n".
        "(see $ENV{EPAGES_CONFIG}/Cartridges.d/$BU.conf)\n"
        if $CoreVersion ne "$Main.$Sub.$Patch";

    return if $HF == 1;
    my $PrevHF = "$Main.$Sub.$Patch.". ($HF - 1);

    die "Hotfix $Options{version} can't be applied because previous hotfix $PrevHF ".
        "not installed yet.\n(not found: $VersionFile)\n"
        unless -f $VersionFile;

    die "Hotfix $Options{version} can't be applied because previous hotfix $PrevHF ".
        "not installed yet.\n(see $VersionFile)\n"
        if $$InstalledVersions !~ /(^|\n)\Q$PrevHF\E(\n|$)/;
}

RunScript(
    'Sub' => \&Main
);
