#!/bin/env perl

use strict;
use File::Basename qw ( dirname );
use feature qw(say);

use DE_EPAGES::Core::API::Script qw ( RunScript );
use DE_EPAGES::Database::API::Config qw( StoreType BusinessUnits StoreTypesWithCartridge );
use DE_EPAGES::Database::API::Connection qw( RunOnStore );
use DE_EPAGES::Trigger::API::XML::HookImportHandler qw (ImportHooks);

sub Main {
    local $| = 1;

    chdir dirname $0;

    my $SourceDir = '../FileChanges/srv/epages/eproot/Cartridges/DE_EPAGES';
    return unless -d $SourceDir;
    chdir $SourceDir;

    my ($Stores, $HookFiles) = _GetImports();

    foreach my $Store (@$Stores) {
        RunOnStore(
            Store => $Store,
            Sub => sub  {
                foreach (@{$HookFiles->{$Store}}) {
                    say qq(ImportHooks($_, $Store));
                    ImportHooks($_);
                }
            },
        );
    }

}

sub _GetImports {
    my $BU;
    push @{$BU->{StoreType($_)}}, $_ foreach @{_GetBusinessUnits()};

    my ($Stores, $HookFiles) = ([], {});
    foreach my $Dir (sort glob '*/Database/XML') {
        my $Cartridge = $Dir;
        $Cartridge =~ s,/.*,,;
        my @StoreTypes = @{StoreTypesWithCartridge("DE_EPAGES::$Cartridge")};

        foreach my $XMLFile (sort glob "$Dir/Hooks*.xml") {
            foreach my $StoreType (@StoreTypes) {
                foreach my $Store (@{$BU->{$StoreType}}) {
                    push @$Stores, $Store unless $Store ~~ @$Stores;
                    push @{$HookFiles->{$Store}}, "$ENV{EPAGES_CARTRIDGES}/DE_EPAGES/$XMLFile";
                }
            }
        }
    }
    return ($Stores, $HookFiles);
}

sub _GetBusinessUnits {
    return [ sort split /\s+/, $ENV{EPAGES_BUSINESS_UNITS} ]
        if $ENV{EPAGES_BUSINESS_UNITS} =~ /\S/;
    return [ sort keys %{BusinessUnits()} ];
}

RunScript(
    'Sub' => \&Main
);
