#!/bin/env perl

use strict;
use File::Basename qw ( dirname );
use feature qw(say);

use DE_EPAGES::Core::API::Script qw ( RunScript );
use DE_EPAGES::Database::API::Config qw( StoreType BusinessUnits StoreTypesWithCartridge );
use DE_EPAGES::Database::API::Connection qw( RunOnStore );
use DE_EPAGES::Object::API::XML::AttributeImportHandler qw( ImportAttributes );
use DE_EPAGES::Object::API::XML::ObjectImportHandler qw (ImportObjects);

sub Main {
    local $| = 1;

    chdir dirname $0;

    my $SourceDir = '../FileChanges/srv/epages/eproot/Cartridges/DE_EPAGES';
    return unless -d $SourceDir;
    chdir $SourceDir;

    my ($Stores, $AttributeFiles, $ObjectFiles) = _GetImports();

    foreach my $Store (@$Stores) {
        RunOnStore(
            Store => $Store,
            Sub => sub  {
                foreach (@{$AttributeFiles->{$Store}}) {
                    say qq(ImportAttributes($_, '/', $Store));
                    ImportAttributes($_, '/');
                }
                foreach (@{$ObjectFiles->{$Store}}) {
                    say qq(ImportObjects($_, '/', $Store));
                    ImportObjects($_, '/');
                }
            },
        );
    }

}

sub _GetImports {
    my $BU;
    push @{$BU->{StoreType($_)}}, $_ foreach @{_GetBusinessUnits()};

    my ($Stores, $AttributeFiles, $ObjectFiles) = ([], {}, {});
    foreach my $Dir (sort glob '*/Database/XML') {
        my $Cartridge = $Dir;
        $Cartridge =~ s,/.*,,;
        my @StoreTypes = @{StoreTypesWithCartridge("DE_EPAGES::$Cartridge")};

        foreach my $XMLFile (sort glob "$Dir/*.xml") {
            foreach my $StoreType (@StoreTypes) {
                foreach my $Store (@{$BU->{$StoreType}}) {
                    push @$Stores, $Store unless $Store ~~ @$Stores;
                    if( $XMLFile =~ /\bTranslation\.(\w+\.)+(\w\w|\w\w-\w\w)\.xml$/ ) {
                        push @{$AttributeFiles->{$Store}}, "$ENV{EPAGES_CARTRIDGES}/DE_EPAGES/$XMLFile";
                    } elsif( $XMLFile !~ /\bHooks[^\/]*\.xml$/ ) {
                        push @{$ObjectFiles->{$Store}}, "$ENV{EPAGES_CARTRIDGES}/DE_EPAGES/$XMLFile";
                    }
                }
            }
        }
    }
    return ($Stores, $AttributeFiles, $ObjectFiles);
}

sub _GetBusinessUnits {
    return [ sort split /\s+/, $ENV{EPAGES_BUSINESS_UNITS} ]
        if $ENV{EPAGES_BUSINESS_UNITS} =~ /\S/;
    return [ sort keys %{BusinessUnits()} ];
}

RunScript(
    'Sub' => \&Main
);
