#!/bin/env perl

use strict;
use File::Basename qw ( dirname );
use feature qw(say);

use DE_EPAGES::Core::API::Script qw ( RunScript );
use DE_EPAGES::DataCache::API::Cache qw( UpdateCache );
use DE_EPAGES::Database::API::Config qw( StoreType BusinessUnits StoreTypesWithCartridge );
use DE_EPAGES::Database::API::Connection qw( RunOnStore GetCurrentDBHandle );
use DE_EPAGES::WebInterface::API::MessageCenter qw( SynchronizeCache );

sub Main {
    local $| = 1;

    chdir dirname $0;

    my $SourceDir = '../FileChanges/srv/epages/eproot/Cartridges/DE_EPAGES';
    return unless -d $SourceDir;
    chdir $SourceDir;

    foreach my $Store (@{_GetTemplates()}) {
        RunOnStore(
            Store => $Store,
            Sub => sub  {
                my $dbi = GetCurrentDBHandle();
                $dbi->do('UPDATE style SET isinvalid=1');

                my $cacheKey = GetCurrentDBHandle()->cacheKey;
                say qq(UpdateCache($Store,'InfoStyle'));
                UpdateCache($cacheKey,'InfoStyle');
                say qq(UpdateCache($Store,'Object'));
                UpdateCache($cacheKey,'Object');
            },
        );
    }
    SynchronizeCache();
}

sub _GetTemplates {
    my $BU;
    push @{$BU->{StoreType($_)}}, $_ foreach @{_GetBusinessUnits()};

    my $Stores = [];
    foreach my $Dir (sort glob '*/Templates') {
        my $Cartridge = $Dir;
        $Cartridge =~ s,/.*,,;

        foreach my $StoreType (@{StoreTypesWithCartridge("DE_EPAGES::$Cartridge")}) {
            next if $StoreType eq 'Site';
            foreach my $Store (@{$BU->{$StoreType}}) {
                push @$Stores, $Store unless $Store ~~ @$Stores;
            }
        }
    }
    return $Stores;
}

sub _GetBusinessUnits {
    return [ sort split /\s+/, $ENV{EPAGES_BUSINESS_UNITS} ]
        if $ENV{EPAGES_BUSINESS_UNITS} =~ /\S/;
    return [ sort keys %{BusinessUnits()} ];
}

RunScript(
    'Sub' => \&Main
);
