#!/bin/env perl

use strict;
use Getopt::Long;
use File::Basename qw(dirname);

use DE_EPAGES::Core::API::File qw ( GetFileContent);
use DE_EPAGES::Core::API::Script qw( RunScript );
use DE_EPAGES::Core::API::SystemCommand qw (SystemCommand);

sub usage {
    die <<END_USAGE;
Usage:
    perl $0 [-nocheck|-check]

Options:
    -check  :   only run perl scripts starting with '[0-9]+-Check'
    -nocheck: do not run perl scripts starting with '[0-9]+-Check'
END_USAGE
}

sub Main {
    local $| = 1;

    my %Options;
    my @GetOpt = qw(check!);
    usage() unless GetOptions(\%Options, @GetOpt);
    $Options{check} //= -1;

    chdir dirname $0;

    my $Run = 'all';
    my $VersionFile = "$ENV{EPAGES_CONFIG}/hotfixes/version.txt";

    if ( -f $VersionFile ) {
        my $Version = GetFileContent('../version.txt');
        my $Chomped = $$Version;
        chomp $Chomped;

        my $InstalledVersions = GetFileContent($VersionFile);
        $Run = 'local' if $$InstalledVersions =~ /(^|\n)\Q$Chomped\E(\n|$)/;
    }

    my $PerlExe = $^O eq 'MSWin32' ? $^X : "$ENV{PERL}";
    foreach my $PerlScript (sort glob '[0-9]*.PL') {
        next if $PerlScript =~ /^\d+-Check/ and $Options{check} == 0;
        next if $PerlScript !~ /^\d+-Check/ and $Options{check} == 1;
        next if $Run eq 'local' and $PerlScript =~ /-shared\.PL/;
        next if $Run ne 'local' and $PerlScript =~ /-local\.PL/;
        SystemCommand( "$PerlExe $PerlScript", {Print => 1} );
        die $! if $!;
    }
}

RunScript(
    'Sub' => \&Main
);
